-- M.A.I.D.  (Mining And Inventory Daemon)
--
-- Add Item Pop-up
--
-- Assembled and written by igrok
-- Portions adopted from AutoJett v2.3 GUI by iry
-- Some portions taken from TGFT TradeAssistant (TA)
--


MAID.UI.addItemPopup = {}   -- Pop-up window for adding new jettison items

MAID.UI.addItemPopup.Show = {}        -- this will show the popup
MAID.UI.addItemPopup.Hide = {}        -- this will hide the popup


-- set to the name of the cargo item selected in the list
MAID.UI.addItemPopup.cargoItemSelected = nil


local cargoitems_sorttbl = {
    [1] = {
        title = "Name",
        alignment = "ALEFT",
        fn = function(a,b)
            return a.Name < b.Name
        end,
        },
    update_entry = function(matrix, index, data)
        matrix:setcell(index, 1, data.Name)
    end,
    on_sel = function (matrix, row, data)
        if(data ~= nil) then
            MAID.UI.addItemPopup.cargoItemSelected = data.Name
        end
    end,
}

MAID.UI.addItemPopup.cargoitems_matrix = MAID.UI:create_matrix(cargoitems_sorttbl, 1)
MAID.UI.addItemPopup.addButton = iup.stationbutton{title="Add Selected Item", expand="HORIZONTAL", hotkey=iup.K_a, action = function()
        if MAID.UI.addItemPopup.cargoItemSelected ~= nil then
            -- add the item to list of monitored cargo
            MAID:addCargoItem(MAID.UI.addItemPopup.cargoItemSelected)

            -- Maybe - remove the item from the list of recent cargo
            -- BROKEN: table.remove(MAID.recentCargo, MAID.UI.addItemPopup.cargoItemSelected)

            MAID.UI:reset_data()
        end
    end}

MAID.UI.addItemPopup.itemNameBox = iup.text{expand="HORIZONTAL", action=function(self, key, value)
        if key == 13 and value ~= "" then MAID.UI.addItemPopup.addManualButton:action() end
    end}
MAID.UI.addItemPopup.addManualButton = iup.stationbutton{title="Add", action = function()
        local item = MAID.UI.addItemPopup.itemNameBox.value
        if item ~= "" then
            MAID:addCargoItem(item)
            MAID.UI:reset_data()
        end
    end}

MAID.UI.addItemPopup.closeButton = iup.stationbutton{title="Close", expand="HORIZONTAL", hotkey=iup.K_e, action = function() MAID.UI.addItemPopup.Hide() end}

local addCargoWidgets = iup.vbox{
    iup.pdarootframe{
        iup.pdasubframebg{
            iup.hbox{
                iup.vbox{
                        -- List of recent cargo
                        iup.label{title="Select from recently picked up cargo:"},
                        MAID.UI.addItemPopup.cargoitems_matrix,
                        MAID.UI.addItemPopup.addButton,
                },
                margin="5x5",
            },
        },
    },
    iup.fill{size="30"},

    iup.pdarootframe{
        iup.pdasubframebg{
            iup.vbox{
                -- Manually add item
                iup.hbox{
                    iup.label{title="Add cargo item manually:"},
                },
                iup.hbox{
                    MAID.UI.addItemPopup.itemNameBox,
                    MAID.UI.addItemPopup.addManualButton,
                },
                margin="5x5",
            },
        },
    },
    iup.fill{size="30"},

    MAID.UI.addItemPopup.closeButton,
}


MAID.UI.addItemPopup.MAIN = iup.dialog{
    iup.stationhighopacityframe{
        iup.stationhighopacityframebg{
            iup.vbox{
                addCargoWidgets,
            },
        },
    },
    border="YES",
    topmost="YES",
    RESIZE="NO",
    MAXBOX="NO",
    MINBOX="NO",
    MENUBOX="NO",
    size='%50x%70',
    DEFAULTESC=MAID.UI.addItemPopup.closeButton,
    BGCOLOR = "0 0 0 256 *",
}
MAID.UI.addItemPopup.MAIN:map()


local function reset_data()
    -- fill the cargo matrix with the relevant data
    MAID.UI.addItemPopup.cargoitems_tbl = {}
    for item,v in pairs(MAID.recentCargo) do
        table.insert(MAID.UI.addItemPopup.cargoitems_tbl,1,{
                Name = item,
            }
        )
    end
    MAID.UI.addItemPopup.cargoitems_matrix:reset(MAID.UI.addItemPopup.cargoitems_tbl)

    -- width of the matrix columns
    local width = getwidth(MAID.UI.addItemPopup.cargoitems_matrix) - Font.Default
    MAID.UI.addItemPopup.cargoitems_matrix.width1 = width     -- Name

    MAID.UI.addItemPopup.itemNameBox.value = ""
end


function MAID.UI.addItemPopup:Show()
    reset_data()
    ShowDialog(MAID.UI.addItemPopup.MAIN,iup.CENTER,iup.CENTER)
end

function MAID.UI.addItemPopup:Hide()
    HideDialog(MAID.UI.addItemPopup.MAIN,iup.CENTER,iup.CENTER)
end



-- this cute snipet allows the app to close/hide when the bound key is pressed
-- i.e. bind 'x' to /storm press x once it launches /storm, press again it closes
function MAID.UI.addItemPopup.MAIN:k_any(char)
    local command = gkinterface.GetCommandForKeyboardBind(char)
    if command == 'maid' then
        MAID.UI.addItemPopup.Hide()
        MAID.UI.Hide()
        return iup.IGNORE
    end
    return iup.CONTINUE
end


